@@ -4,7 +4,7 @@ from typing import Optional, List
 class Mailable:
     def __init__(self,
                  subject: str,
-                 to_addr: str,
+                 to_addr: List[str],
                  cc: Optional[List[str]] = None,
                  bcc: Optional[List[str]] = None,
                  from_addr: Optional[str] = None,
