@@ -22,11 +22,11 @@ class SlackClient(NotificationChannel):
         if msg.has_blocks():
             payload['blocks'] = msg.blocks
             if msg.has_mentions:
-                payload['blocks'] = msg.with_mention(msg.blocks)
+                payload['blocks'] = msg.with_mentions(msg.blocks)
         else:
             payload['text'] = msg.text
             if msg.has_mentions:
-                payload['text'] = msg.with_mention(msg.text)
+                payload['text'] = msg.with_mentions(msg.text)
 
         if msg.has_link:
             payload['link_names'] = 1
