@@ -26,12 +26,12 @@ class SlackMessage:
     def has_blocks(self):
         return self.blocks is not None and len(self.blocks) > 0
 
-    def with_mention(self, message_data):
+    def with_mentions(self, message_data):
         mentions = self._mention_text()
         if isinstance(message_data, str):
             return '{} {}'.format(mentions, message_data)
         if isinstance(message_data, list):
-            return [{"type": "plain_text", "text": mentions}] + message_data
+            return [{'type': 'section', 'text': {"type": "plain_text", "text": mentions}}] + message_data
         return message_data
 
     def _mention_text(self):
